@@ -3,7 +3,6 @@ package Pcore::API::Moz::Account;
 use Pcore -class, -result, -const;
 use Pcore::Util::Data qw[to_b64 to_uri to_json from_json];
 use Pcore::Util::Digest qw[hmac_sha1];
-use Pcore::HTTP::CookieJar;
 
 use overload    #
   q[""] => sub {
@@ -15,7 +14,7 @@ has moz => ( is => 'ro', isa => InstanceOf ['Pcore::API::Moz'], required => 1 );
 has id  => ( is => 'ro', isa => Str, required => 1 );
 has key => ( is => 'ro', isa => Str, required => 1 );
 
-has _cookie_jar => ( is => 'ro', isa => InstanceOf ['Pcore::HTTP::CookieJar'], default => sub { Pcore::HTTP::CookieJar->new }, init_arg => undef );
+has _cookie_jar => ( is => 'ro', isa => HashRef, default => sub { {} }, init_arg => undef );
 
 has next_req_ts => ( is => 'ro', isa => PositiveOrZeroInt, default => 0, init_arg => undef );
 
